@@ -1,6 +1,6 @@
 import pyodbc
 from .DatabaseConnector import DatabaseConnector
-from ....configuration.models.database_config import DatabaseConfig
+from ....configuration.models.database.database_config import DatabaseConfig
 
 
 class MssqlDbConnector(DatabaseConnector):
