@@ -1,25 +1,25 @@
 import json
-import os
+import sys
 from unittest import TestCase
 
+from pdip.base import Pdi
 from pdip.api.app import FlaskAppWrapper
-from pdip.data import DatabaseSessionManager
-from pdip.dependency.container import DependencyContainer
 
 
 class TestBasicAppWithError(TestCase):
     def setUp(self):
-        root_directory = os.path.abspath(os.path.join(
-            os.path.dirname(os.path.abspath(__file__))))
-        DependencyContainer.initialize_service(root_directory=root_directory)
-        engine = DependencyContainer.Instance.get(
-            DatabaseSessionManager).engine
-        DependencyContainer.Base.metadata.create_all(engine)
-        self.client = DependencyContainer.Instance.injector.get(
-            FlaskAppWrapper).test_client()
+        self.pdi = Pdi()
+        self.pdi.drop_all()
+        self.pdi.create_all()
+        self.client = self.pdi.get(FlaskAppWrapper).test_client()
 
     def tearDown(self):
-        DependencyContainer.cleanup()
+        if hasattr(self,'pdi') and self.pdi is not None:
+            self.pdi.cleanup()
+            del self.pdi
+        modules = [y for y in sys.modules if 'pdip' in y]
+        for module in modules:
+            del module
         return super().tearDown()
 
     def print_error_detail(self, data):
